@@ -280,11 +280,8 @@ class MyWhatify:
 
     def get_ensemble_id(self, task_name):
         with allure.step('getting the ensemble ID of task name: ' + str(task_name)):
-            ensemble_id = my_toolkit.Ensemble.get_ensemble_id(search_term=task_name)
-            # task_id = self.get_tasks_list(search_term=task_name) 151231
-            # task_id = task_id[-1]['id']
-            # ensemble_id = self.get_ensemble_list(task_id=task_id)[-1]['id']
-            return ensemble_id
+            task_id = my_toolkit.Task.get_task_id(task_name=task_name)
+            return my_toolkit.Ensemble.get_ensemble_id(task_id=task_id)
 
     def get_data_file(self, data_name='car_sdk_demo.csv'):
         with allure.step('getting csv from data file for data_name: ' + str(data_name)):
